@@ -188,7 +188,7 @@ public:
     bool configureTransport(const QString &identifier, Transport *transport, QWidget *parent);
 
     void initializeTransport(const QString &identifier, Transport *transport);
-public Q_SLOTS:
+public:
     /**
       Returns true if there are no mail transports at all.
     */
@@ -291,8 +291,6 @@ private:
 
     Q_PRIVATE_SLOT(d, void slotTransportsChanged())
     Q_PRIVATE_SLOT(d, void slotWalletOpened(bool success))
-    Q_PRIVATE_SLOT(d, void dbusServiceUnregistered())
-    Q_PRIVATE_SLOT(d, void jobResult(KJob *job))
 };
 } // namespace MailTransport
 
