@@ -39,7 +39,6 @@ class AddTransportDialogNG::Private
 public:
     Private(AddTransportDialogNG *qq)
         : q(qq)
-        , okButton(nullptr)
     {
     }
 
@@ -54,7 +53,7 @@ public:
     void readConfig();
 
     AddTransportDialogNG *const q;
-    QPushButton *okButton;
+    QPushButton *okButton = nullptr;
     ::Ui::AddTransportDialog ui;
 };
 
@@ -67,7 +66,7 @@ void AddTransportDialogNG::Private::writeConfig()
 void AddTransportDialogNG::Private::readConfig()
 {
     KConfigGroup group(KSharedConfig::openConfig(), "AddTransportDialog");
-    const QSize sizeDialog = group.readEntry("Size", QSize(300, TransportManager::self()->types().size() > 1 ? 200 : 80));
+    const QSize sizeDialog = group.readEntry("Size", QSize(300, TransportManager::self()->types().size() > 1 ? 300 : 160));
     if (sizeDialog.isValid()) {
         q->resize(sizeDialog);
     }
@@ -140,14 +139,18 @@ AddTransportDialogNG::AddTransportDialogNG(QWidget *parent)
     d->ui.typeListView->setFocus();
 
     // Connect user input.
-    connect(d->ui.typeListView, SIGNAL(itemClicked(QTreeWidgetItem *,int)),
-            this, SLOT(updateOkButton()));
-    connect(d->ui.typeListView, SIGNAL(itemSelectionChanged()),
-            this, SLOT(updateOkButton()));
-    connect(d->ui.typeListView, SIGNAL(itemDoubleClicked(QTreeWidgetItem *,int)),
-            this, SLOT(doubleClicked()));
-    connect(d->ui.name, SIGNAL(textChanged(QString)),
-            this, SLOT(updateOkButton()));
+    connect(d->ui.typeListView, &QTreeWidget::itemClicked, this, [this]() {
+        d->updateOkButton();
+    });
+    connect(d->ui.typeListView, &QTreeWidget::itemSelectionChanged, this, [this]() {
+        d->updateOkButton();
+    });
+    connect(d->ui.typeListView, &QTreeWidget::itemDoubleClicked, this, [this]() {
+        d->doubleClicked();
+    });
+    connect(d->ui.name, &QLineEdit:: textChanged, this, [this]() {
+        d->updateOkButton();
+    });
     d->readConfig();
 }
 
