@@ -39,7 +39,7 @@ public:
     void editItem(QTreeWidgetItem *item, int column = 0);
 
 protected Q_SLOTS:
-    void commitData(QWidget *editor) Q_DECL_OVERRIDE;
+    void commitData(QWidget *editor) override;
 
 private Q_SLOTS:
     void fillTransportList();
