@@ -48,9 +48,8 @@ MessageQueuer::MessageQueuer()
     if (!Akonadi::Control::start()) {
         qFatal("Could not start Akonadi server.");
     }
-    QVBoxLayout *vbox = new QVBoxLayout;
+    QVBoxLayout *vbox = new QVBoxLayout(this);
     vbox->setMargin(0);
-    setLayout(vbox);
 
     mComboBox = new TransportComboBox(this);
     mComboBox->setEditable(true);
@@ -107,9 +106,9 @@ void MessageQueuer::sendOnDateClicked()
     dt->setDateTime(QDateTime::currentDateTime());
     dt->setDisplayFormat(QStringLiteral("hh:mm:ss"));
     layout->addWidget(dt);
-    auto box = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
-    connect(box, SIGNAL(accepted()), dialog, SLOT(accept()));
-    connect(box, SIGNAL(rejected()), dialog, SLOT(reject()));
+    auto box = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, dialog);
+    connect(box, &QDialogButtonBox::accepted, dialog.data(), &QDialog::accept);
+    connect(box, &QDialogButtonBox::rejected, dialog.data(), &QDialog::reject);
     layout->addWidget(box);
     if (!dialog->exec() || !dialog) {
         return;
@@ -143,12 +142,12 @@ MessageQueueJob *MessageQueuer::createQueueJob()
     job->addressAttribute().setBcc(mBccEdit->text().isEmpty()
                                    ? QStringList() : mBccEdit->text().split(QLatin1Char(',')));
 
-    connect(job, SIGNAL(result(KJob *)),
-            SLOT(jobResult(KJob *)));
-    connect(job, SIGNAL(percent(KJob *,ulong)),
-            SLOT(jobPercent(KJob *,ulong)));
-    connect(job, SIGNAL(infoMessage(KJob *,QString,QString)),
-            SLOT(jobInfoMessage(KJob *,QString,QString)));
+    connect(job, SIGNAL(result(KJob*)),
+            SLOT(jobResult(KJob*)));
+    connect(job, SIGNAL(percent(KJob*,ulong)),
+            SLOT(jobPercent(KJob*,ulong)));
+    connect(job, SIGNAL(infoMessage(KJob*,QString,QString)),
+            SLOT(jobInfoMessage(KJob*,QString,QString)));
 
     return job;
 }
